==> jc-1.4.0.tar.gz: javax/swing/JMenu__24AccessibleJMenu.h <==
// public class javax.swing.JMenu$AccessibleJMenu

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class ee99f57bdd9990a javax_swing_JMenu__24AccessibleJMenu
// @dep_class 5dbfdfd99aace194 javax_swing_JMenuItem__24AccessibleJMenuItem

// header file dependencies
// @dep_header javax_swing_JMenuItem__24AccessibleJMenuItem

#include "javax/swing/JMenuItem__24AccessibleJMenuItem.h"

#ifndef _JC_javax_swing_JMenu__24AccessibleJMenu_H_
#define _JC_javax_swing_JMenu__24AccessibleJMenu_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_Accessible$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleSelection$object;
struct _jc_javax_swing_JMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$sub_refs	_jc_javax_swing_JMenu__24AccessibleJMenu$sub_refs;
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$sub_nonrefs	_jc_javax_swing_JMenu__24AccessibleJMenu$sub_nonrefs;
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$refs	_jc_javax_swing_JMenu__24AccessibleJMenu$refs;
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$nonrefs	_jc_javax_swing_JMenu__24AccessibleJMenu$nonrefs;
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$object	_jc_javax_swing_JMenu__24AccessibleJMenu$object;

typedef const struct _jc_javax_swing_JMenu__24AccessibleJMenu$vmethods	_jc_javax_swing_JMenu__24AccessibleJMenu$vmethods;
typedef const struct _jc_javax_swing_JMenu__24AccessibleJMenu$vtable	_jc_javax_swing_JMenu__24AccessibleJMenu$vtable;
typedef const struct _jc_javax_swing_JMenu__24AccessibleJMenu$vtype	_jc_javax_swing_JMenu__24AccessibleJMenu$vtype;

// Constructors
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$_init$54bf35fff7e58733(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, struct _jc_javax_swing_JMenu$object *);

// Virtual methods
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$addAccessibleSelection$56941b0f37670b20(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$clearAccessibleSelection$cb31a113ff3fcbbb(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
extern struct _jc_object *_jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleChild$98cf334feace704a(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
extern jint _jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleChildrenCount$01361302630f8ed1(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
extern struct _jc_object *_jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleSelection$c46d975f1c9b64bf(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
extern struct _jc_object *_jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleSelection$5dfd61a966af4ade(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
extern jint _jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleSelectionCount$13a41fcf69093855(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
extern jboolean _jc_javax_swing_JMenu__24AccessibleJMenu$method$isAccessibleChildSelected$8f763c666aff0912(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$removeAccessibleSelection$dcf2aa1b76f63590(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$selectAllAccessibleSelection$bd1af813979d098a(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$addAccessibleSelection$56941b0f37670b20;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$clearAccessibleSelection$cb31a113ff3fcbbb;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleChild$98cf334feace704a;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleChildrenCount$01361302630f8ed1;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleSelection$c46d975f1c9b64bf;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleSelection$5dfd61a966af4ade;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleSelectionCount$13a41fcf69093855;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$isAccessibleChildSelected$8f763c666aff0912;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$removeAccessibleSelection$dcf2aa1b76f63590;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$selectAllAccessibleSelection$bd1af813979d098a;

// Virtual methods structure
struct _jc_javax_swing_JMenu__24AccessibleJMenu$vmethods {
	void	(*addAccessibleSelection$56941b0f37670b20)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
	void	(*clearAccessibleSelection$cb31a113ff3fcbbb)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
	struct _jc_object	*(*getAccessibleChild$98cf334feace704a)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
	jint	(*getAccessibleChildrenCount$01361302630f8ed1)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
	struct _jc_object	*(*getAccessibleSelection$c46d975f1c9b64bf)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
	struct _jc_object	*(*getAccessibleSelection$5dfd61a966af4ade)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
	jint	(*getAccessibleSelectionCount$13a41fcf69093855)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
	jboolean	(*isAccessibleChildSelected$8f763c666aff0912)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
	void	(*removeAccessibleSelection$dcf2aa1b76f63590)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint);
	void	(*selectAllAccessibleSelection$bd1af813979d098a)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *);
};

// Vtable
struct _jc_javax_swing_JMenu__24AccessibleJMenu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods	javax_swing_JMenuItem__24AccessibleJMenuItem;
	_jc_javax_swing_JMenu__24AccessibleJMenu$vmethods	javax_swing_JMenu__24AccessibleJMenu;
};

// Vtype
struct _jc_javax_swing_JMenu__24AccessibleJMenu$vtype {
	_jc_type			type;
	_jc_javax_swing_JMenu__24AccessibleJMenu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24AccessibleJMenu$sub_refs {
	struct _jc_javax_swing_JMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JMenu__24AccessibleJMenu$refs {
    _jc_javax_swing_JMenu__24AccessibleJMenu$sub_refs	javax_swing_JMenu__24AccessibleJMenu;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24AccessibleJMenu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JMenu__24AccessibleJMenu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_JMenu__24AccessibleJMenu$sub_nonrefs	javax_swing_JMenu__24AccessibleJMenu;
};

// Object instance structure
struct _jc_javax_swing_JMenu__24AccessibleJMenu$object {
	_jc_javax_swing_JMenu__24AccessibleJMenu$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JMenu__24AccessibleJMenu$vtype	*vtype;
	_jc_javax_swing_JMenu__24AccessibleJMenu$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JMenu__24AccessibleJMenu$vtype _jc_javax_swing_JMenu__24AccessibleJMenu$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JMenu__24AccessibleJMenu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JMenu__24AccessibleJMenu$class_object;

#endif	/* _JC_javax_swing_JMenu__24AccessibleJMenu_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JMenu__24AccessibleJMenu.h <==
// public class javax.swing.JMenu$AccessibleJMenu

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class bbfc736d4a3ab5bd javax_swing_JMenu__24AccessibleJMenu
// @dep_class 5dbfdfd99aace194 javax_swing_JMenuItem__24AccessibleJMenuItem

// header file dependencies
// @dep_header javax_swing_JMenuItem__24AccessibleJMenuItem

#include "javax/swing/JMenuItem__24AccessibleJMenuItem.h"

#ifndef _JC_javax_swing_JMenu__24AccessibleJMenu_H_
#define _JC_javax_swing_JMenu__24AccessibleJMenu_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_Accessible$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleSelection$object;
struct _jc_javax_swing_JMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$sub_refs	_jc_javax_swing_JMenu__24AccessibleJMenu$sub_refs;
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$sub_nonrefs	_jc_javax_swing_JMenu__24AccessibleJMenu$sub_nonrefs;
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$refs	_jc_javax_swing_JMenu__24AccessibleJMenu$refs;
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$nonrefs	_jc_javax_swing_JMenu__24AccessibleJMenu$nonrefs;
typedef struct _jc_javax_swing_JMenu__24AccessibleJMenu$object	_jc_javax_swing_JMenu__24AccessibleJMenu$object;

typedef const struct _jc_javax_swing_JMenu__24AccessibleJMenu$vmethods	_jc_javax_swing_JMenu__24AccessibleJMenu$vmethods;
typedef const struct _jc_javax_swing_JMenu__24AccessibleJMenu$vtable	_jc_javax_swing_JMenu__24AccessibleJMenu$vtable;
typedef const struct _jc_javax_swing_JMenu__24AccessibleJMenu$vtype	_jc_javax_swing_JMenu__24AccessibleJMenu$vtype;

// Constructors
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$_init$54bf35fff7e58733(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, struct _jc_javax_swing_JMenu$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$addAccessibleSelection$56941b0f37670b20(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$clearAccessibleSelection$cb31a113ff3fcbbb(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleChild$98cf334feace704a(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleChildrenCount$01361302630f8ed1(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleSelection$c46d975f1c9b64bf(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleSelection$5dfd61a966af4ade(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_JMenu__24AccessibleJMenu$method$getAccessibleSelectionCount$13a41fcf69093855(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_JMenu__24AccessibleJMenu$method$isAccessibleChildSelected$8f763c666aff0912(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$removeAccessibleSelection$dcf2aa1b76f63590(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JMenu__24AccessibleJMenu$method$selectAllAccessibleSelection$bd1af813979d098a(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$addAccessibleSelection$56941b0f37670b20;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$clearAccessibleSelection$cb31a113ff3fcbbb;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleChild$98cf334feace704a;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleChildrenCount$01361302630f8ed1;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleSelection$c46d975f1c9b64bf;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleSelection$5dfd61a966af4ade;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$getAccessibleSelectionCount$13a41fcf69093855;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$isAccessibleChildSelected$8f763c666aff0912;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$removeAccessibleSelection$dcf2aa1b76f63590;
extern _jc_method _jc_javax_swing_JMenu__24AccessibleJMenu$method_info$selectAllAccessibleSelection$bd1af813979d098a;

// Virtual methods structure
struct _jc_javax_swing_JMenu__24AccessibleJMenu$vmethods {
	void	(*addAccessibleSelection$56941b0f37670b20)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
	void	(*clearAccessibleSelection$cb31a113ff3fcbbb)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleChild$98cf334feace704a)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
	jint	(*getAccessibleChildrenCount$01361302630f8ed1)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleSelection$c46d975f1c9b64bf)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleSelection$5dfd61a966af4ade)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
	jint	(*getAccessibleSelectionCount$13a41fcf69093855)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
	jboolean	(*isAccessibleChildSelected$8f763c666aff0912)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
	void	(*removeAccessibleSelection$dcf2aa1b76f63590)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *, jint) _JC_JCNI_ATTR;
	void	(*selectAllAccessibleSelection$bd1af813979d098a)(_jc_env *, struct _jc_javax_swing_JMenu__24AccessibleJMenu$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JMenu__24AccessibleJMenu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods	javax_swing_JMenuItem__24AccessibleJMenuItem;
	_jc_javax_swing_JMenu__24AccessibleJMenu$vmethods	javax_swing_JMenu__24AccessibleJMenu;
};

// Vtype
struct _jc_javax_swing_JMenu__24AccessibleJMenu$vtype {
	_jc_type			type;
	_jc_javax_swing_JMenu__24AccessibleJMenu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24AccessibleJMenu$sub_refs {
	struct _jc_javax_swing_JMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JMenu__24AccessibleJMenu$refs {
    _jc_javax_swing_JMenu__24AccessibleJMenu$sub_refs	javax_swing_JMenu__24AccessibleJMenu;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24AccessibleJMenu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JMenu__24AccessibleJMenu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_JMenu__24AccessibleJMenu$sub_nonrefs	javax_swing_JMenu__24AccessibleJMenu;
};

// Object instance structure
struct _jc_javax_swing_JMenu__24AccessibleJMenu$object {
	_jc_javax_swing_JMenu__24AccessibleJMenu$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JMenu__24AccessibleJMenu$vtype	*vtype;
	_jc_javax_swing_JMenu__24AccessibleJMenu$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JMenu__24AccessibleJMenu$vtype _jc_javax_swing_JMenu__24AccessibleJMenu$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JMenu__24AccessibleJMenu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JMenu__24AccessibleJMenu$class_object;

#endif	/* _JC_javax_swing_JMenu__24AccessibleJMenu_H_ */
